@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.CommonFunctions.inc.php 394 2010-11-12 14:22:42Z jacky672 $
+ * @version   SVN: $Id: class.CommonFunctions.inc.php 570 2012-04-16 07:10:52Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -30,8 +30,27 @@ class CommonFunctions
      *
      * @var string
      */
-    const PSI_VERSION = '3.0.10';
-    
+    const PSI_VERSION = '3.0.17';
+
+    public static $PSI_VERSION_STRING = self::PSI_VERSION;
+
+    /**
+     * get svn version info
+     *
+     * @return  none
+     */
+    public static function checkForSVN()
+    {
+        if  (file_exists (dirname(__FILE__) . '/.svn/entries')){
+          restore_error_handler();
+          $contents = file_get_contents(dirname(__FILE__) . '/.svn/entries');
+          set_error_handler('errorHandlerPsi');
+          if ($contents && preg_match("/dir\n(.+)/", $contents, $matches))
+            self::$PSI_VERSION_STRING = self::PSI_VERSION."-r".$matches[1];
+        }
+    }
+
+
     /**
      * Find a system program, do also path checking when not running on WINNT
      * on WINNT we simply return the name with the exe extension to the program name
@@ -224,7 +243,7 @@ class CommonFunctions
      */
     public static function checkForExtensions($arrExt = array())
     {
-        $arrReq = array('simplexml', 'pcre', 'xml', 'mbstring');
+        $arrReq = array('simplexml', 'pcre', 'xml', 'mbstring', 'dom');
         $extensions = array_merge($arrExt, $arrReq);
         $text = "";
         $error = false;
@@ -267,8 +286,12 @@ class CommonFunctions
         
         while ($time >= 0) {
             $read = array($pipes[1]);
+/*
             while (!feof($read[0]) && ($n = stream_select($read, $w, $e, $time)) !== false && $n > 0 && strlen($c = fgetc($read[0])) > 0) {
                 $out .= $c;
+*/
+            while (!feof($read[0]) && ($n = stream_select($read, $w, $e, $time)) !== false && $n > 0) {
+                $out .= fread($read[0], 4096);
             }
             --$time;
         }
@@ -276,8 +299,12 @@ class CommonFunctions
         $time = $sek;
         while ($time >= 0) {
             $read = array($pipes[2]);
+/*
             while (!feof($read[0]) && ($n = stream_select($read, $w, $e, $time)) !== false && $n > 0 && strlen($c = fgetc($read[0])) > 0) {
                 $err .= $c;
+*/
+            while (!feof($read[0]) && ($n = stream_select($read, $w, $e, $time)) !== false && $n > 0) {
+                $err .= fread($read[0], 4096);
             }
             --$time;
         }
