@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.Linux.inc.php 422 2011-01-21 12:42:25Z jacky672 $
+ * @version   SVN: $Id: class.Linux.inc.php 558 2012-04-03 09:42:42Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -443,6 +443,17 @@ class Linux extends OS
                     $dev->setTxBytes($stats[8]);
                     $dev->setErrors($stats[2] + $stats[10]);
                     $dev->setDrops($stats[3] + $stats[11]);
+                    if (defined('PSI_SHOW_NETWORK_INFOS') && (PSI_SHOW_NETWORK_INFOS) && (CommonFunctions::executeProgram('ifconfig', trim($dev_name).' 2>/dev/null', $bufr2, PSI_DEBUG))) {
+                        $bufe2 = preg_split("/\n/", $bufr2, -1, PREG_SPLIT_NO_EMPTY);
+                        foreach ($bufe2 as $buf2) {
+                            if (preg_match('/\s+encap:Ethernet\s+HWaddr\s([^\s]*)/i', $buf2, $ar_buf2))
+                                $dev->setInfo(preg_replace('/:/', '-', $ar_buf2[1]));
+                            else if (preg_match('/^\s+inet\saddr:([^\s]*)/i', $buf2, $ar_buf2))
+                                     $dev->setInfo(($dev->getInfo()?$dev->getInfo().';':'').$ar_buf2[1]);
+                                 else if (preg_match('/^\s+inet6\saddr:\s([^\/]*)(.*)\s+Scope:[GH]/i', $buf2, $ar_buf2))
+                                      $dev->setInfo(($dev->getInfo()?$dev->getInfo().';':'').$ar_buf2[1]);
+                        }
+                    }
                     $this->sys->setNetDevices($dev);
                 }
             }
@@ -496,7 +507,7 @@ class Linux extends OS
      */
     private function _filesystems()
     {
-        $arrResult = Parser::df("-P");
+        $arrResult = Parser::df("-P 2>/dev/null");
         foreach ($arrResult as $dev) {
             $this->sys->setDiskDevices($dev);
         }
@@ -512,8 +523,8 @@ class Linux extends OS
         if (!$list) {
             return;
         }
-        // We have the '2> /dev/null' because Ubuntu gives an error on this command which causes the distro to be unknown
-        if (CommonFunctions::executeProgram('lsb_release', '-a 2> /dev/null', $distro_info, PSI_DEBUG)) {
+        // We have the '2>/dev/null' because Ubuntu gives an error on this command which causes the distro to be unknown
+        if (CommonFunctions::executeProgram('lsb_release', '-a 2>/dev/null', $distro_info, PSI_DEBUG)) {
             $distro_tmp = preg_split("/\n/", $distro_info, -1, PREG_SPLIT_NO_EMPTY);
             foreach ($distro_tmp as $info) {
                 $info_tmp = preg_split('/:/', $info, 2);
