@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.XML.inc.php 423 2011-01-21 12:53:46Z jacky672 $
+ * @version   SVN: $Id: class.XML.inc.php 573 2012-05-02 13:46:31Z jacky672 $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -149,6 +149,8 @@ class XML
                 $device->addAttribute('TxBytes', $dev->getTxBytes());
                 $device->addAttribute('Err', $dev->getErrors());
                 $device->addAttribute('Drops', $dev->getDrops());
+                if ( defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS && ($dev->getInfo())) 
+                    $device->addAttribute('Info', $dev->getInfo());
             }
         }
     }
@@ -280,7 +282,7 @@ class XML
         $mount->addAttribute('Percent', $dev->getPercentUsed());
         if (PSI_SHOW_MOUNT_OPTION === true) {
             if ($dev->getOptions() !== null) {
-                $mount->addAttribute('MountOptions', $dev->getOptions());
+                $mount->addAttribute('MountOptions', preg_replace("/,/",", ",$dev->getOptions()));
             }
         }
         if ($dev->getPercentInodesUsed() !== null) {
@@ -495,7 +497,7 @@ class XML
         $this->_xml = new SimpleXMLExtended(simplexml_import_dom($dom), $this->_sysinfo->getEncoding());
         
         $generation = $this->_xml->addChild('Generation');
-        $generation->addAttribute('version', CommonFunctions::PSI_VERSION);
+        $generation->addAttribute('version', CommonFunctions::$PSI_VERSION_STRING);
         $generation->addAttribute('timestamp', time());
         $options = $this->_xml->addChild('Options');
         $options->addAttribute('tempFormat', defined('PSI_TEMP_FORMAT') ? PSI_TEMP_FORMAT : 'c');
