@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: js.php 438 2011-02-11 18:29:29Z jacky672 $
+ * @version   SVN: $Id: js.php 506 2011-10-22 18:29:42Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
 /**
@@ -47,13 +47,14 @@ if ($script != null && file_exists($script) && is_readable($script)) {
     } else {
         if(defined("PSI_JS_COMPRESSION")) {
             switch (PSI_JS_COMPRESSION) {
-                case "JSMin":
-                    echo JSMin::minify($filecontent);
-                    break;
-                case "JavaScriptPacker":
+                case "Normal":
                     $packer = new JavaScriptPacker($filecontent);
                     echo $packer->pack();
                     break;
+                case "None":
+                    $packer = new JavaScriptPacker($filecontent,0);
+                    echo $packer->pack();
+                    break;
                 default: 
                     echo $filecontent;
                     break;
