@@ -18,7 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 //
-// $Id: phpsysinfo.js 419 2011-01-18 08:28:56Z jacky672 $
+// $Id: phpsysinfo.js 547 2012-03-22 09:44:38Z namiltd $
 //
 
 /*global $, jQuery */
@@ -237,8 +237,8 @@ function changeLanguage(plugin) {
  */
 function filesystemtable() {
     var html = "";
-    html += "        <h2>" + genlang(30, false) + "</h2>\n";
-    html += "        <table id=\"filesystemTable\" cellspacing=\"0\">\n";
+    html += "<h2>" + genlang(30, false) + "</h2>\n";
+    html += "        <table id=\"filesystemTable\" style=\"border-spacing:0;\">\n";
     html += "          <thead>\n";
     html += "            <tr>\n";
     html += "              <th>" + genlang(31, false) + "</th>\n";
@@ -551,6 +551,8 @@ function createBar(size) {
  */
 function refreshVitals(xml) {
     var hostname = "", ip = "", kernel = "", distro = "", icon = "", uptime = "", users = 0, loadavg = "";
+    var lastboot = 0, timestamp = Number(new Date());
+    
     $("Vitals", xml).each(function getVitals(id) {
         hostname = $(this).attr("Hostname");
         ip = $(this).attr("IPAddr");
@@ -558,6 +560,7 @@ function refreshVitals(xml) {
         distro = $(this).attr("Distro");
         icon = $(this).attr("Distroicon");
         uptime = formatUptime(parseInt($(this).attr("Uptime"), 10));
+        lastboot = new Date(timestamp - (parseInt($(this).attr("Uptime"), 10)*1000));
         users = parseInt($(this).attr("Users"), 10);
         loadavg = $(this).attr("LoadAvg");
         if ($(this).attr("CPULoad") !== undefined) {
@@ -571,6 +574,7 @@ function refreshVitals(xml) {
         $("#s_kernel").html(kernel);
         $("#s_distro").html("<img src='./gfx/images/" + icon + "' alt='Icon' height='16' width='16' style='vertical-align:middle;' />&nbsp;" + distro);
         $("#s_uptime").html(uptime);
+        $("#s_lastboot").html(lastboot.toGMTString()); //toGMTString() or toLocaleString()
         $("#s_users").html(users);
         $("#s_loadavg").html(loadavg);
     });
@@ -670,7 +674,7 @@ function fillHWDevice(xml, type, tree, rootposition) {
 function refreshHardware(xml) {
     var html = "", tree = [], closed = [], index = 0;
     $("#hardware").empty();
-    html += "  <h2>" + genlang(10, false) + "</h2>\n";
+    html += "<h2>" + genlang(10, false) + "</h2>\n";
     html += "  <table id=\"HardwareTree\" class=\"tablemain\" style=\"width:100%;\">\n";
     html += "   <tbody class=\"tree\">\n";
     
@@ -723,16 +727,68 @@ function refreshHardware(xml) {
  * @param {jQuery} xml phpSysInfo-XML
  */
 function refreshNetwork(xml) {
-    var name = "", rx = 0, tx = 0, er = 0, dr = 0;
-    $("#tbody_network").empty();
+    var tree = [], closed = [], html0= "", html1= "" ,html = "", isinfo = false;
+    $("#network").empty();
+
+    html0 += "<h2>" + genlang(21, false) + "</h2>\n";
+
+    html1 += "   <thead>\n";
+    html1 += "    <tr>\n";
+    html1 += "     <th>" + genlang(22, true) + "</th>\n";
+    html1 += "     <th class=\"right\" style=\"width:50px;\">" + genlang(23, true) + "</th>\n";
+    html1 += "     <th class=\"right\" style=\"width:50px;\">" + genlang(24, true) + "</th>\n";
+    html1 += "     <th class=\"right\" style=\"width:50px;\">" + genlang(25, true) + "</th>\n";
+    html1 += "    </tr>\n";
+    html1 += "   </thead>\n";
+
     $("Network NetDevice", xml).each(function getDevice(id) {
+        var name = "", rx = 0, tx = 0, er = 0, dr = 0, info = "", networkindex = 0;
         name = $(this).attr("Name");
         rx = parseInt($(this).attr("RxBytes"), 10);
         tx = parseInt($(this).attr("TxBytes"), 10);
         er = parseInt($(this).attr("Err"), 10);
         dr = parseInt($(this).attr("Drops"), 10);
-        $("#tbody_network").append("<tr><td>" + name + "</td><td class=\"right\">" + formatBytes(rx, xml) + "</td><td class=\"right\">" + formatBytes(tx, xml) + "</td><td class=\"right\">" + er.toString() + "/" + dr.toString() + "</td></tr>");
+        html +="<tr><td>" + name + "</td><td class=\"right\">" + formatBytes(rx, xml) + "</td><td class=\"right\">" + formatBytes(tx, xml) + "</td><td class=\"right\">" + er.toString() + "/" + dr.toString() + "</td></tr>";
+        
+        networkindex = tree.push(0);
+        
+        info = $(this).attr("Info");
+        if ( (info !== undefined) && (info != "") ) {
+           var i =0, infos = info.split(";");
+           isinfo = true;
+           for(i = 0; i < infos.length; i++){
+              html +="<tr><td>" + infos[i] + "</td><td></td><td></td><td></td></tr>";
+              tree.push(networkindex);
+              closed.push(networkindex);
+            }
+        }
     });
+    html += "</tbody>\n";
+    html += "</table>\n";
+    if (isinfo) {
+       html0 += "<table id=\"NetworkTree\" class=\"tablemain\" style=\"border-spacing:0;\">\n";
+       html1 += "   <tbody class=\"tree\">\n";
+    } else {
+       html0 += "<table id=\"NetworkTree\" class=\"stripeMe\" style=\"border-spacing:0;\">\n";
+       html1 += "   <tbody class=\"tbody_network\">\n";
+    }
+    $("#network").append(html0+html1+html);
+
+    if (isinfo) $("#NetworkTree").jqTreeTable(tree, {
+        openImg: "./gfx/treeTable/tv-collapsable.gif",
+        shutImg: "./gfx/treeTable/tv-expandable.gif",
+        leafImg: "./gfx/treeTable/tv-item.gif",
+        lastOpenImg: "./gfx/treeTable/tv-collapsable-last.gif",
+        lastShutImg: "./gfx/treeTable/tv-expandable-last.gif",
+        lastLeafImg: "./gfx/treeTable/tv-item-last.gif",
+        vertLineImg: "./gfx/treeTable/vertline.gif",
+        blankImg: "./gfx/treeTable/blank.gif",
+        collapse: closed,
+        column: 0,
+        striped: true,
+        highlight: false,
+        state: false
+      });
 }
 
 /**
@@ -743,7 +799,7 @@ function refreshMemory(xml) {
     var html = "", tree = [], closed = [];
     
     $("#memory").empty();
-    html += "  <h2>" + genlang(27, false) + "</h2>\n";
+    html += "<h2>" + genlang(27, false) + "</h2>\n";
     html += "  <table id=\"MemoryTree\" class=\"tablemain\" style=\"width:100%;\">\n";
     html += "   <thead>\n";
     html += "    <tr>\n";
@@ -973,7 +1029,7 @@ function refreshFan(xml) {
  */
 function refreshUps(xml) {
     var html = "", tree = [], closed = [], index = 0, values = false;
-    html += "        <h2><span id=\"lang_068\">UPS information</span></h2>\n";
+    html += "<h2><span id=\"lang_068\">UPS information</span></h2>\n";
     html += "        <table class=\"tablemain\" id=\"UPSTree\">\n";
     html += "          <tbody class=\"tree\">\n";
     
@@ -1040,7 +1096,7 @@ function refreshUps(xml) {
             html += "<tr><td style=\"width:160px\">" + genlang(81, false) + "</td><td>" + time_left_minutes + "&nbsp;" + genlang(83, false) + "</td></tr>\n";
             tree.push(index);
         }
-		values=true;
+        values=true;
     });
     html += "          </tbody>\n";
     html += "        </table>\n";
@@ -1210,10 +1266,10 @@ jQuery.fn.dataTableExt.oSort['span-number-desc'] = function sortNumberDesc(a, b)
 function buildBlock(plugin, translationid, reload) {
     var block = "", reloadpic = "";
     if (reload) {
-        reloadpic = "<img id=\"Reload_" + plugin + "Table\" src=\"./gfx/reload.png\" alt=\"reload\" style=\"vertical-align:middle;border=0px;\" />&nbsp;";
+        reloadpic = "<img id=\"Reload_" + plugin + "Table\" src=\"./gfx/reload.png\" alt=\"reload\" title=\"reload\" style=\"vertical-align:middle;float:right;cursor:pointer;border:0px;\" />&nbsp;";
     }
-    block += "      <div id=\"Plugin_" + plugin + "\" style=\"display:none;float:left;margin:10px 0pt 0pt 10px;padding: 1px;\">\n";
-    block += "        <h2>" + reloadpic + genlang(translationid, false, plugin) + "</h2>\n<span id=\"DateTime_" + plugin + "\" style=\"margin-left:10px;\"></span>";
+    block += "      <div id=\"Plugin_" + plugin + "\" class=\"plugin\" style=\"display:none;\">\n";
+    block += "<h2>" + reloadpic + genlang(translationid, false, plugin) + "</h2>\n";
     block += "      </div>\n";
     return block;
 }
@@ -1247,13 +1303,14 @@ function datetime() {
     minutes = (minute < 10) ? "0" + minute.toString() : minute.toString();
     hours = (hour < 10) ? "0" + hour.toString() : hour.toString();
     
-    return days + "." + months + "." + years + "&nbsp;" + hours + ":" + minutes;
+    return days + "." + months + "." + years + " - " + hours + ":" + minutes;
 }
 
 /**
  * insert dynamically a js script file into the website
  * @param {String} name name of the script that should be included
  */
+/*
 function appendjs(name) {
     var scrptE, hdEl;
     scrptE = document.createElement("script");
@@ -1262,11 +1319,12 @@ function appendjs(name) {
     scrptE.setAttribute("type", "text/javascript");
     hdEl.appendChild(scrptE);
 }
-
+*/
 /**
  * insert dynamically a css file into the website
  * @param {String} name name of the css file that should be included
  */
+/*
 function appendcss(name) {
     var scrptE, hdEl;
     scrptE = document.createElement("link");
@@ -1276,3 +1334,4 @@ function appendcss(name) {
     scrptE.setAttribute("href", name);
     hdEl.appendChild(scrptE);
 }
+*/
