@@ -1,4 +1,4 @@
-﻿/***************************************************************************
+/***************************************************************************
  *   Copyright (C) 2008 by phpSysInfo - A PHP System Information Script    *
  *   http://phpsysinfo.sourceforge.net/                                    *
  *                                                                         *
@@ -18,7 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-/*global $, jQuery, buildBlock, datetime, plugin_translate, genlang, appendcss, createBar */
+/*global $, jQuery, buildBlock, datetime, plugin_translate, genlang, createBar */
 
 "use strict";
 
@@ -57,7 +57,7 @@ function updatenotifier_populate(xml) {
 function updatenotifier_buildTable() {
     var html = "";
 
-    html += "<table id=\"Plugin_UpdateNotifierTable\" cellspacing=\"0\">\n";
+    html += "<table id=\"Plugin_UpdateNotifierTable\" style=\"border-spacing:0;\">\n";
     html += "  <thead>\n";
     html += "    <tr>\n";
     html += "      <th>" + genlang(2, true, "UpdateNotifier") + "</th>\n";
